<?php
include("../db/db.php");

if ($_SERVER['REQUEST_METHOD'] == "POST") {
    $drop = isset($_REQUEST['drop']) ? $_REQUEST['drop'] : null;
    $carType = isset($_REQUEST['carType']) ? $_REQUEST['carType'] : null;
    $pickup = isset($_REQUEST['pickup']) ? $_REQUEST['pickup'] : null;
    $distance = isset($_REQUEST['distance']) ? floatval($_REQUEST['distance']) : 0;
    $date = isset($_REQUEST['date']) ? $_REQUEST['date'] : null;
    $time = isset($_REQUEST['time']) ? $_REQUEST['time'] : null;

    // Ensure required fields are provided
    if (!$drop || !$carType || !$pickup || !$distance || !$date) {
        echo "Required data missing.";
        exit;
    }

    // Query for fixed price
    $fixedPriceQuery = "SELECT price FROM fixed_rate WHERE pick_up = ? AND `drop_off` = ? AND car_type = ?";
    $fixedPriceStmt = mysqli_prepare($con, $fixedPriceQuery);

    if ($fixedPriceStmt) {
        mysqli_stmt_bind_param($fixedPriceStmt, "sss", $pickup, $drop, $carType);
        mysqli_stmt_execute($fixedPriceStmt);
        $fixedPriceResult = mysqli_stmt_get_result($fixedPriceStmt);

        if (mysqli_num_rows($fixedPriceResult) > 0) {
            // Fixed price found
            $fixedPriceRow = mysqli_fetch_assoc($fixedPriceResult);
            $fixedPrice = $fixedPriceRow['price'];

            // // Query to get the percentage based on date range and time
            // $percentageQuery = "SELECT * FROM sugar_price WHERE (? BETWEEN from_date AND till_date) OR (? BETWEEN from_time AND till_time)";
            // $percentageStmt = mysqli_prepare($con, $percentageQuery);

            // if ($percentageStmt) {
            //     mysqli_stmt_bind_param($percentageStmt, "ss", $date, $time);
            //     mysqli_stmt_execute($percentageStmt);
            //     $percentageResult = mysqli_stmt_get_result($percentageStmt);

            //     if (mysqli_num_rows($percentageResult) > 0) {
            //         $percentageRow = mysqli_fetch_assoc($percentageResult);
            //         $percentage = $percentageRow['type'];
            //         $rate = $percentageRow['rate'];

            //         if ($percentage == 'Percent') {
            //             $additionalFare = ($fixedPrice * $rate) / 100;
            //             $fixedPrice += $additionalFare;
            //         } elseif ($percentage == 'Amount') {
            //             $fixedPrice += $rate;
            //         }
            //     }
            // }

            // Output the fixed price
            echo number_format($fixedPrice);
        } else {
            // Use prepared statement to prevent SQL injection
            $query = "SELECT * FROM fare_amount WHERE car_type = ? AND miles_from <= ? AND miles_to >= ?";
            $stmt = mysqli_prepare($con, $query);

            if ($stmt) {
                mysqli_stmt_bind_param($stmt, "sdd", $carType, $distance, $distance);
                mysqli_stmt_execute($stmt);
                $result = mysqli_stmt_get_result($stmt);

                if (mysqli_num_rows($result) > 0) {
                    $row = mysqli_fetch_assoc($result);
                    $firstMilePrice = $row['first_mile_price'];
                    $perMilePrice = $row['per_mile_price'];

                    $totalFare = $firstMilePrice + ($distance - 1) * $perMilePrice;

                    // Query to get the percentage based on date range and time
                    $percentageQuery = "SELECT * FROM sugar_amount WHERE (? BETWEEN from_date AND till_date) OR (? BETWEEN from_time AND till_time)";
                    $percentageStmt = mysqli_prepare($con, $percentageQuery);

                    if ($percentageStmt) {
                        mysqli_stmt_bind_param($percentageStmt, "ss", $date, $time);
                        mysqli_stmt_execute($percentageStmt);
                        $percentageResult = mysqli_stmt_get_result($percentageStmt);

                        if (mysqli_num_rows($percentageResult) > 0) {
                            $percentageRow = mysqli_fetch_assoc($percentageResult);
                            $percentage = $percentageRow['type'];
                            $rate = $percentageRow['rate'];

                            if ($percentage == 'Percent') {
                                $additionalFare = ($totalFare * $rate) / 100;
                                $totalFare += $additionalFare;
                            } elseif ($percentage == 'Amount') {
                                $totalFare += $rate;
                            }
                        }
                    }

                    // Output the calculated fare
                    echo number_format($totalFare);
                } else {
                    // Handle case where no fare information found
                    echo "No fare information found.";
                }
            } else {
                // Handle database query error
                echo "Error in the database query: " . mysqli_error($con);
            }
        }
    } else {
        // Handle error in preparing fixed price query
        echo "Error in preparing the query: " . mysqli_error($con);
    }
} else {
    // Handle case where no POST data is submitted
    echo "No data submitted.";
}
?>
