<?php
// Database connection
include("../db/db.php");

// Include Twilio SDK
require_once __DIR__ . '/../vendor/autoload.php';
use Twilio\Rest\Client;

// Start the session
session_start();

if ($_SERVER['REQUEST_METHOD'] == "POST") {
    // Retrieve the posted variables safely
    $dispatchId = $con->real_escape_string($_REQUEST['dispatchId']); 
    $dispatchJobId = $con->real_escape_string($_REQUEST['dispatchJobId']);

    // Set default timezone to London
    $timezone = 'Europe/London';  
    if (isset($_REQUEST['timezone']) && in_array($_REQUEST['timezone'], timezone_identifiers_list())) {
        $timezone = $_REQUEST['timezone'];
    }
    date_default_timezone_set($timezone);
    
    $currentDateTime = date('d/m/Y H:i');  // Date and time in "DD/MM/YYYY HH:MM" format

    // Check if username is correctly retrieved from the session
    if (isset($_SESSION['username'])) {
        $username = $con->real_escape_string(htmlspecialchars($_SESSION['username']));
    } else {
        $username = ''; 
        error_log("Username not set in session.");
    }

    // Prepare query for updating the bookings table
    $query = "UPDATE `bookins` SET 
              `dispatch_DriverId` = '$dispatchId',
              `allocate_DriverId` = '$dispatchId-waiting',
              `dispatch_time` = '$currentDateTime',
              `dispatch_by` = '$username'
              WHERE `id` = '$dispatchJobId'";

    // Execute the update query
    $result = mysqli_query($con, $query);
    
    if ($result) {
        // Insert the dispatch history if the previous query was successful
        $insertHistoryQuery = "INSERT INTO dispatch_history 
            (`job_id`, `driver_id`, `dispatch_time`, `dispatch_by`) 
            VALUES ('$dispatchJobId', '$dispatchId', '$currentDateTime', '$username')";
        $con->query($insertHistoryQuery);

        // Fetch the driver's phone number
        $driverQuery = "SELECT `Phone` FROM `drivers` WHERE `Driver_id`='$dispatchId'";
        $driverResult = mysqli_query($con, $driverQuery);

        if ($driverResult && $driverDetails = mysqli_fetch_assoc($driverResult)) {
            $recipientNumber = 'whatsapp:44' . $driverDetails['Phone'];

            // Fetch job details from the bookings table
            $jobDetailsQuery = "SELECT * FROM `bookins` WHERE `id`='$dispatchJobId'";
            $jobDetailsResult = mysqli_query($con, $jobDetailsQuery);

            if ($jobDetailsResult && $jobDetails = mysqli_fetch_assoc($jobDetailsResult)) {
                $pickupLocation = $jobDetails['pickup'];
                $dropOffLocation = $jobDetails['dropoff'];
                $fareNotes = $jobDetails['fare'];
                $name = $jobDetails['name'];
                $phone = $jobDetails['phone'];
                $carType = $jobDetails['car_type'];
                $id = $jobDetails['id'];
                $date = $jobDetails['date'];
                $time = $jobDetails['time'];
                $note = $jobDetails['message'];
                $via = $jobDetails['via'];

                if (empty($note)) {
                    $note = 'No Additional notes';
                }

                if (empty($via)) {
                    $via = 'NAN';
                }

                // Twilio API credentials
                $accountSid = 'AC99d0d3c9498a4b645ad2e373df7f3c08';
                $authToken = '0ce47f034a69367a2fa8b00250f1088c';
                $twilioNumber = '+442080506606'; 
                $messagingServiceSid = 'MG140e7c6045bc2fefe61a9d8c579cae6e';
                $contentSid = 'HX715593ba04d3cae82a7462f204d56638';

                try {
                    // Initialize Twilio client
                    $twilio = new Client($accountSid, $authToken);

                    // Send the WhatsApp message
                    $message = $twilio->messages
                        ->create(
                            $recipientNumber,
                            [
                                'from' => 'whatsapp:' . $twilioNumber,
                                'contentSid' => $contentSid,
                                'messagingServiceSid' => $messagingServiceSid,
                                'contentVariables' => json_encode([
                                    "1" => $id,
                                    "2" => $date,
                                    "3" => $time,
                                    "4" => $pickupLocation,
                                    "5" => $via,
                                    "6" => $dropOffLocation,
                                    "7" => $fareNotes,
                                    "8" => $name,
                                    "9" => $phone,
                                    "10" => $carType,
                                    "11" => $note,
                                ]),
                            ]
                        );

                    // If everything is successful, return success response
                    $response = array('success' => true, 'message' => 'Dispatch Job Successfully');
                } catch (Exception $e) {
                    // Log and return Twilio API error
                    error_log("Twilio API Error: " . $e->getMessage());
                    $response = array('success' => false, 'message' => 'Twilio API Error: ' . $e->getMessage());
                }
            } else {
                // Error in fetching job details
                $response = array('success' => false, 'message' => 'Error fetching job details: ' . mysqli_error($con));
            }
        } else {
            // Error in fetching driver details
            $response = array('success' => false, 'message' => 'Error fetching driver details: ' . mysqli_error($con));
        }
    } else {
        // Error in updating records
        $response = array('success' => false, 'message' => 'Error updating records: ' . mysqli_error($con));
    }

    // Send the final response as JSON and exit the script
    echo json_encode($response);
    exit;
}
?>
