<?php
include("../db/db.php"); // Include your database connection file

// Enable error reporting for debugging
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

header('Content-Type: application/json'); // Set the response content type to JSON

// Function to fetch data using cURL
function fetchData($url) {
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    $response = curl_exec($ch);
    if (curl_errno($ch)) {
        echo json_encode(['status' => 'error', 'message' => 'Failed to fetch data: ' . curl_error($ch)]);
        exit();
    }
    curl_close($ch);
    return $response;
}

if (isset($_POST['pickup_location'])) {
    $pickup_location = $_POST['pickup_location'];

    // Set default dropoff location to Central London if not provided
    $dropoff_location = $_POST['dropoff_location'] ?? "Central London";

    // Mapbox token for geocoding and directions matrix
    $mapbox_token = 'pk.eyJ1IjoiaXRsb2dpc29sdXRpb25zIiwiYSI6ImNtMjNkZGo5czA0eHMyanM2aWN2YTY1YTAifQ.l4Fh6K-t8pMiNcQx8ngwxw';

    // Get the coordinates for pickup location
    $pickup_geocode_response = fetchData("https://api.mapbox.com/geocoding/v5/mapbox.places/" . urlencode($pickup_location) . ".json?access_token=$mapbox_token");
    $pickup_geocode_data = json_decode($pickup_geocode_response, true);

    // Get the coordinates for dropoff location
    $dropoff_geocode_response = fetchData("https://api.mapbox.com/geocoding/v5/mapbox.places/" . urlencode($dropoff_location) . ".json?access_token=$mapbox_token");
    $dropoff_geocode_data = json_decode($dropoff_geocode_response, true);

    if (!empty($pickup_geocode_data['features']) && !empty($dropoff_geocode_data['features'])) {
        // Extract pickup and dropoff coordinates
        $pickup_lat = $pickup_geocode_data['features'][0]['center'][1];
        $pickup_lng = $pickup_geocode_data['features'][0]['center'][0];
        $dropoff_lat = $dropoff_geocode_data['features'][0]['center'][1];
        $dropoff_lng = $dropoff_geocode_data['features'][0]['center'][0];

        // Get all drivers with plot = 'plot'
        $query = "SELECT Driver_id, Name, latitude, longitude FROM drivers WHERE plot = 'plot'";
        $result = mysqli_query($con, $query);

        if (!$result) {
            echo json_encode(['status' => 'error', 'message' => 'Database query failed: ' . mysqli_error($con)]);
            exit();
        }

        $etas = [];

        while ($driver = mysqli_fetch_assoc($result)) {
            $driver_id = $driver['Driver_id'];
            $driver_name = $driver['Name'];
            $driver_lat = $driver['latitude'];
            $driver_long = $driver['longitude'];

            // Use Mapbox Matrix API to calculate the ETA between driver and pickup location
            $matrix_url = "https://api.mapbox.com/directions-matrix/v1/mapbox/driving/$driver_long,$driver_lat;$pickup_lng,$pickup_lat?access_token=$mapbox_token&annotations=duration";

            $matrix_response = fetchData($matrix_url);
            $matrix_data = json_decode($matrix_response, true);

            if (isset($matrix_data['durations'][0][1])) {
                // Convert duration to minutes
                $duration_in_minutes = round($matrix_data['durations'][0][1] / 60);

                // Get location name based on driver's coordinates
                $geocode_url = "https://api.mapbox.com/geocoding/v5/mapbox.places/$driver_long,$driver_lat.json?access_token=$mapbox_token";
                $geocode_response = fetchData($geocode_url);
                $geocode_data = json_decode($geocode_response, true);

                $locationName = (!empty($geocode_data['features'])) ? $geocode_data['features'][0]['place_name'] : 'Unknown location';

                $etas[] = [
                    'driver_id' => $driver_id,
                    'driver_name' => $driver_name,
                    'eta' => $duration_in_minutes . ' min',
                    'zone' => $locationName
                ];
            } else {
                $etas[] = [
                    'driver_id' => $driver_id,
                    'driver_name' => $driver_name,
                    'eta' => 'N/A',
                    'zone' => 'N/A'
                ];
            }
        }

        echo json_encode(['status' => 'success', 'etas' => $etas, 'pickup_lat' => $pickup_lat, 'pickup_lng' => $pickup_lng, 'dropoff_lat' => $dropoff_lat, 'dropoff_lng' => $dropoff_lng]);
    } else {
        echo json_encode(['status' => 'error', 'message' => 'Failed to fetch coordinates for the given locations.']);
    }
} else {
    echo json_encode(['status' => 'error', 'message' => 'Pickup location not provided.']);
}

mysqli_close($con);
?>
