<?php
include("../db/db.php");

header('Content-Type: application/json');

// Enable error reporting
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Read the call data from the temporary file
$filename = 'call_data.json';

if (file_exists($filename) && filesize($filename) > 0) {
    $callData = file_get_contents($filename);

    // Ensure valid JSON response
    $data = json_decode($callData, true);
    if (json_last_error() === JSON_ERROR_NONE) {
        // Iterate over the calls and add customer names
        foreach ($data as &$call) {
            $from = $call['from'];

            // Query to find the customer name
            $stmt = $con->prepare("SELECT name FROM bookins WHERE phone = ?");
            if ($stmt === false) {
                echo json_encode(['status' => 'error', 'message' => 'Prepare failed: ' . $con->error]);
                exit;
            }
            
            $stmt->bind_param("s", $from);
            if (!$stmt->execute()) {
                echo json_encode(['status' => 'error', 'message' => 'Execute failed: ' . $stmt->error]);
                exit;
            }

            $stmt->bind_result($customerName);
            if (!$stmt->fetch()) {
                $customerName = 'Unknown';
            }

            $call['name'] = $customerName;

            $stmt->close();
        }

        echo json_encode(['status' => 'success', 'calls' => $data]);
    } else {
        echo json_encode(['status' => 'error', 'message' => 'Invalid JSON data']);
    }
} else {
    echo json_encode(['status' => 'no_data']);
}

// Close the database connection
$con->close();
?>
