<?php
$mapboxAccessToken = 'pk.eyJ1IjoiaXRsb2dpc29sdXRpb25zIiwiYSI6ImNtMjNkZGo5czA0eHMyanM2aWN2YTY1YTAifQ.l4Fh6K-t8pMiNcQx8ngwxw'; // Replace with your actual Mapbox access token

// Function to geocode an address to latitude and longitude
function geocodeAddress($address, $accessToken) {
    $url = "https://api.mapbox.com/geocoding/v5/mapbox.places/" . 
           urlencode($address) . ".json?access_token=" . $accessToken;

    // Log the URL for debugging
    error_log("Geocoding URL: $url");

    // Initialize a CURL session
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    $response = curl_exec($ch);
    curl_close($ch);

    // Decode the response
    $responseData = json_decode($response, true);

    // Log the response for debugging
    error_log("Geocoding Response for '$address': " . print_r($responseData, true));

    // Check if the API call was successful and if there are features returned
    if (isset($responseData['features']) && count($responseData['features']) > 0) {
        return [
            'latitude' => $responseData['features'][0]['geometry']['coordinates'][1], // Latitude
            'longitude' => $responseData['features'][0]['geometry']['coordinates'][0] // Longitude
        ];
    }

    // Return null coordinates if not found
    return ['latitude' => null, 'longitude' => null];
}

// Include database connection
include("../db/db.php");

if (isset($_GET['jobId'])) {
    $jobId = $_GET['jobId'];

    // Fetch dispatch driver ID from the bookings table
    $driverQuery = "SELECT dispatch_DriverId FROM bookins WHERE id = ?";
    $stmt = mysqli_prepare($con, $driverQuery);
    mysqli_stmt_bind_param($stmt, "i", $jobId);
    mysqli_stmt_execute($stmt);
    mysqli_stmt_bind_result($stmt, $driverId);
    mysqli_stmt_fetch($stmt);
    mysqli_stmt_close($stmt);

    // Fetch driver's latitude and longitude from the drivers table
    $query = "SELECT latitude, longitude, Registration, Phone, Make_By, Car_Model, Color, Driver_id FROM drivers WHERE Driver_id = ?";
    $stmt = mysqli_prepare($con, $query);
    mysqli_stmt_bind_param($stmt, "i", $driverId);
    mysqli_stmt_execute($stmt);
    mysqli_stmt_bind_result($stmt, $driverLatitude, $driverLongitude, $registration, $phone, $make, $model, $color, $driverId);
    mysqli_stmt_fetch($stmt);
    mysqli_stmt_close($stmt);

    // Fetch pickup and dropoff locations' names from the bookins table
    $jobQuery = "SELECT pickup, dropoff FROM bookins WHERE id = ?";
    $stmt = mysqli_prepare($con, $jobQuery);
    mysqli_stmt_bind_param($stmt, "i", $jobId);
    mysqli_stmt_execute($stmt);
    mysqli_stmt_bind_result($stmt, $pickupName, $dropoffName);
    mysqli_stmt_fetch($stmt);
    mysqli_stmt_close($stmt);

    // Log the pickup and dropoff addresses for debugging
    error_log("Pickup Address: $pickupName");
    error_log("Dropoff Address: $dropoffName");

    // Geocode pickup and dropoff locations
    $pickupCoordinates = geocodeAddress($pickupName, $mapboxAccessToken);
    $dropoffCoordinates = geocodeAddress($dropoffName, $mapboxAccessToken);

    // Check if geocoding was successful
    if ($pickupCoordinates['latitude'] !== null && $dropoffCoordinates['latitude'] !== null) {
        // Prepare response with valid coordinates
        $pickupLatitude = $pickupCoordinates['latitude'];
        $pickupLongitude = $pickupCoordinates['longitude'];
        $dropoffLatitude = $dropoffCoordinates['latitude'];
        $dropoffLongitude = $dropoffCoordinates['longitude'];
    } else {
        // Handle case where geocoding failed
        error_log("Geocoding failed for pickup: '$pickupName' or dropoff: '$dropoffName'");
        $pickupLatitude = $pickupLongitude = $dropoffLatitude = $dropoffLongitude = null;
    }

    // Close the database connection
    mysqli_close($con);

    // Output driver and job details as JSON
    $responseData = [
        'driverLatitude' => $driverLatitude,
        'driverLongitude' => $driverLongitude,
        'pickupLatitude' => $pickupLatitude,
        'pickupLongitude' => $pickupLongitude,
        'dropoffLatitude' => $dropoffLatitude,
        'dropoffLongitude' => $dropoffLongitude,
        'carModel' => $model,
        'registration' => $registration,
        'phone' => $phone,
        'make' => $make,
        'color' => $color,
        'driverId' => $driverId,
        'pickup' => $pickupName,
        'dropoff' => $dropoffName
    ];
    
    header('Content-Type: application/json');
    echo json_encode($responseData);
}
?>
