<?php
include("../db/db.php");

header('Content-Type: application/json');

// Read raw JSON data from the request body for POST requests
$input = file_get_contents('php://input');
$data = json_decode($input, true);

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Check if the data is valid
    if (isset($data['job_id']) && isset($data['accepted'])) {
        $jobId = $data['job_id'];
        $accepted = $data['accepted'];
    } else {
        $response = array('success' => false, 'message' => 'Missing or invalid parameters');
        echo json_encode($response);
        exit;
    }

    if ($accepted !== null) {
        if ($jobId !== null) {
            // Set the timezone to London
            date_default_timezone_set('Europe/London');
            $currentTime = date('d-m-Y H:i');
            $query = $con->prepare("UPDATE bookins SET accepted = ?, dispatch_time = ?, accept_time = ? WHERE id = ?");
            $query->bind_param('sssi', $accepted, $currentTime, $currentTime, $jobId);
            $result = $query->execute();

            if ($result) {
                if ($accepted == '1') {
                    $dispatchQuery = $con->prepare("SELECT dispatch_DriverId FROM bookins WHERE id = ?");
                    $dispatchQuery->bind_param('i', $jobId);
                    $dispatchQuery->execute();
                    $dispatchResult = $dispatchQuery->get_result();

                    if ($dispatchResult && $dispatchResult->num_rows > 0) {
                        $row = $dispatchResult->fetch_assoc();
                        $driverId = $row['dispatch_DriverId'];
                        // Update the status of the driver to "unplot"
                        $updateDriverQuery = $con->prepare("UPDATE drivers SET plot = 'unplot' WHERE Driver_id = ?");
                        $updateDriverQuery->bind_param('i', $driverId);
                        $updateDriverResult = $updateDriverQuery->execute();

                        if ($updateDriverResult) {
                            $updateHistoryQuery = $con->prepare("UPDATE dispatch_history SET accepted = 1 WHERE job_id = ? AND driver_id = ? AND accepted = 0");
                            $updateHistoryQuery->bind_param('ii', $jobId, $driverId);
                            $updateHistoryQuery->execute();
                            $response = array('success' => true, 'message' => 'Job accepted');
                        } else {
                            $response = array('success' => false, 'message' => 'Failed to update driver status');
                        }
                    } else {
                        $response = array('success' => false, 'message' => 'Driver not found');
                    }
                } elseif ($accepted == '0') {
                    // Assuming $driverId should be fetched similarly to acceptance case
                    $dispatchQuery = $con->prepare("SELECT dispatch_DriverId FROM bookins WHERE id = ?");
                    $dispatchQuery->bind_param('i', $jobId);
                    $dispatchQuery->execute();
                    $dispatchResult = $dispatchQuery->get_result();

                    if ($dispatchResult && $dispatchResult->num_rows > 0) {
                        $row = $dispatchResult->fetch_assoc();
                        $driverId = $row['dispatch_DriverId'];
                        $queryReject = $con->prepare("UPDATE bookins SET allocate_DriverId = CONCAT(?, '-Reject'), dispatch_DriverId = '' WHERE id = ?");
                        $queryReject->bind_param('si', $driverId, $jobId);
                        $result = $queryReject->execute();

                        if ($result) {
                        $updateHistoryQuery = "UPDATE dispatch_history SET reject_time = ? WHERE job_id = ? AND driver_id = ? AND accepted = 0";
                        $historyStmt = $con->prepare($updateHistoryQuery);
                        $historyStmt->bind_param('sii', $currentTime, $jobId, $driverId);
                        $historyStmt->execute();
                            $response = array('success' => true, 'message' => 'Job rejected');
                        } else {
                            $response = array('success' => false, 'message' => 'Failed to reject job');
                        }
                    } else {
                        $response = array('success' => false, 'message' => 'Driver not found for rejection');
                    }
                }
            } else {
                $response = array('success' => false, 'message' => 'Error accepting/rejecting job: ' . $con->error);
            }
        } else {
            $response = array('success' => false, 'message' => 'Missing parameter');
        }
    } else {
        $response = array('success' => false, 'message' => 'Invalid parameter');
    }
} else {
    $response = array('success' => false, 'message' => 'Invalid request method');
}

echo json_encode($response);

mysqli_close($con);

?>
