<?php
// Display errors for debugging (optional, can be removed in production)
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

header('Content-Type: application/json'); // Set the content type to JSON

include("../db/db.php");

$response = array();

// Check if the database connection is successful
if (!$con) {
    $response['status'] = 'error';
    $response['message'] = 'Database connection failed: ' . mysqli_connect_error();
    echo json_encode($response);
    exit;
}

// Ensure the request is POST
if ($_SERVER['REQUEST_METHOD'] == "POST") {

    // Check if the required fields are set
    if (isset($_POST['driverId'])  && isset($_POST['message']) && isset($_POST['type'])) {

        // Retrieve and sanitize inputs
        $sender = trim($_POST['driverId']);
        $message = trim($_POST['message']);

        // Prepare an SQL statement to prevent SQL injection
        $stmt = $con->prepare("INSERT INTO conversation (sender, receiver, message) VALUES (?, ?, ?)");

        // Check if statement preparation was successful
        if ($stmt === false) {
            $response['status'] = 'error';
            $response['message'] = 'Statement preparation failed: ' . $con->error;
        } else {
            // Bind the parameters
            $receiver = 'web';
            $stmt->bind_param("sss", $sender, $receiver, $message);

            // Execute the query and check for errors
            if ($stmt->execute()) {
                $response['status'] = 'success';
                $response['message'] = 'Message sent successfully';
            } else {
                $response['status'] = 'error';
                $response['message'] = 'Execution failed: ' . $stmt->error;
            }

            // Close the prepared statement
            $stmt->close();
        }
    } else {
        // Return error if any field is missing
        $response['status'] = 'error';
        $response['message'] = 'Missing required fields';
    }

} else {
    // Return error for unsupported request method
    $response['status'] = 'error';
    $response['message'] = 'Invalid request method';
}

// Close the database connection
mysqli_close($con);

// Return the response as JSON
echo json_encode($response);
?>
