// Function to calculate distance and fare
function calculateDistanceAndFare() {
    var pickup = $('#pickup').val();
    var drop = $('#drops').val();
    var carType = $('#cartype').val();
    var distance = $("#display_distance").val();
    var date = $("#dateInput").val();
    var time = $("#timeInput").val();

    console.log("date", date);
    console.log("time", time);

    if (pickup && drop) {
        $.ajax({
            type: 'POST',
            url: './action/Submit.php',
            data: {
                pickup: pickup,
                drop: drop,
                carType: carType,
                distance: distance,
                date: date,
                time: time
            },
            cache: false,
            success: function (response) {
                console.log("price", response);
                $('#priceVal').val(response);
            },
            error: function () {
                console.log("error");
            }
        });
    } else {
        console.log("add locations");
    }
}
// Add event listeners to car type, pickup location, drop location inputs, and Mapbox input suggestions
$('#cartype, #pickup, #drops, .via').on('input change', function () {
    console.log("Input changed");
    calculateDistanceAndFare();
});
// Initialize Mapbox
mapboxgl.accessToken = 'pk.eyJ1IjoiaXRsb2dpc29sdXRpb25zIiwiYSI6ImNtMjNkZGo5czA0eHMyanM2aWN2YTY1YTAifQ.l4Fh6K-t8pMiNcQx8ngwxw';


    const map = new mapboxgl.Map({
        container: 'map_canvas',
        style: 'mapbox://styles/mapbox/streets-v12',
        center: [-79.4512, 43.6568],
        zoom: 13
    });

$('#exampleModalmap').on('shown.bs.modal', function () {
    map.resize(); // Call the resize method
});

// Also listen for window resize events
window.addEventListener('resize', () => {
    map.resize();
});

// Initialize directions
const directions = new MapboxDirections({
    accessToken: mapboxgl.accessToken,
    unit: 'metric',
    profile: 'mapbox/driving',
    interactive: false,
     showMarkers: false
    
});
map.addControl(directions, 'top-right');

let pickupCoordinates = null;
let pickupName = '';
let waypointsCoordinates = [null, null, null, null];
let waypointsNames = ['', '', '', ''];
let dropCoordinates = null;
let dropName = '';

let markers = []; // Store markers to be able to clear them later

function addMarker(coordinates, label, name) {
    const marker = new mapboxgl.Marker({ color: "#6f42c1" })
        .setLngLat(coordinates)
        .addTo(map);

    const popup = new mapboxgl.Popup({
        closeButton: false,
        closeOnClick: false
    }).setHTML(`<h4>${label}</h4><p>${name}</p>`).addTo(map);

    marker.setPopup(popup);
    markers.push(marker); // Add marker to markers array for tracking
}

function clearMarkers() {
    markers.forEach(marker => marker.remove()); // Remove each marker
    markers = []; // Clear markers array
}

function updateMarkers() {
    clearMarkers();
    if (pickupCoordinates) {
        addMarker(pickupCoordinates, 'Pickup', pickupName);
    }
    waypointsCoordinates.forEach((coords, index) => {
        if (coords) {
            addMarker(coords, `Via ${index + 1}`, waypointsNames[index]);
        }
    });
    if (dropCoordinates) {
        addMarker(dropCoordinates, 'Destination', dropName);
    }
}
// Function to check and fetch the route
function removeVia(index) {
    // Set the selected via location to null in waypointsCoordinates
    waypointsCoordinates[index] = null;
    waypointsNames[index] = ''; // Clear the name if you store it separately
    checkAndFetchRoute(); // Recalculate the route after removing the via
}

function checkAndFetchRoute() {
    const pickupField = document.getElementById('pickup');
    const dropField = document.getElementById('drops');

    if (pickupCoordinates && dropCoordinates) {
        // Set the route if both coordinates are available
        directions.setOrigin(pickupCoordinates);
        directions.setDestination(dropCoordinates);

        // Clear existing waypoints in `directions`
        while (directions.getWaypoints().length) {
            directions.removeWaypoint(0);
        }

        // Add new waypoints only if they exist in waypointsCoordinates
        waypointsCoordinates.forEach(coords => {
            if (coords) {
                directions.addWaypoint(directions.getWaypoints().length, coords);
            }
        });

        updateMarkers();
    } else if (pickupField.value && dropField.value) {
        // Fetch coordinates if addresses are filled in fields
        fetchCoordinatesFromAddress(pickupField.value, dropField.value);
    } else {
        // Clear route if coordinates are missing
        directions.setOrigin('');
        directions.setDestination('');
        while (directions.getWaypoints().length) {
            directions.removeWaypoint(0);
        }
        updateMarkers();
    }
}

function removeVia(index) {
    // Remove the selected waypoint in `waypointsCoordinates`
    waypointsCoordinates.splice(index, 1); // Remove the waypoint at the specific index
    checkAndFetchRoute(); // Recalculate the route after removing the via
}

function fetchCoordinatesFromAddress(pickupAddress, dropAddress) {
    if (!pickupCoordinates && pickupAddress) {
        // Fetch pickup coordinates
        fetch(`https://api.mapbox.com/geocoding/v5/mapbox.places/${encodeURIComponent(pickupAddress)}.json?access_token=${mapboxgl.accessToken}`)
            .then(response => response.json())
            .then(data => {
                if (data.features && data.features.length > 0) {
                    pickupCoordinates = data.features[0].geometry.coordinates;
                    checkAndFetchRoute(); // Call function again with updated pickupCoordinates
                }
            });
    }

    if (!dropCoordinates && dropAddress) {
        // Fetch drop coordinates
        fetch(`https://api.mapbox.com/geocoding/v5/mapbox.places/${encodeURIComponent(dropAddress)}.json?access_token=${mapboxgl.accessToken}`)
            .then(response => response.json())
            .then(data => {
                if (data.features && data.features.length > 0) {
                    dropCoordinates = data.features[0].geometry.coordinates;
                    checkAndFetchRoute(); // Call function again with updated dropCoordinates
                }
            });
    }
}


// Geocoder function to attach autocomplete to custom input
function addGeocoderToInput(inputId) {
    const inputElement = document.getElementById(inputId);
    const suggestionsContainer = document.createElement('div');
    suggestionsContainer.className = 'suggestions';
    inputElement.parentNode.appendChild(suggestionsContainer);

    inputElement.addEventListener('input', function () {
        const query = inputElement.value;

        if (query) {
            fetch(`https://api.mapbox.com/geocoding/v5/mapbox.places/${encodeURIComponent(query)}.json?access_token=${mapboxgl.accessToken}`)
                .then(response => response.json())
                .then(data => {
                    suggestionsContainer.innerHTML = '';
                    if (data.features.length > 0) {
                        suggestionsContainer.style.display = 'block';
                        data.features.forEach((feature, index) => {
                            const suggestionItem = document.createElement('div');
                            suggestionItem.className = 'suggestion-item';
                            suggestionItem.innerText = feature.place_name;
                            suggestionItem.addEventListener('click', () => {
                                inputElement.value = feature.place_name;
                                suggestionsContainer.style.display = 'none';
                                const coordinates = feature.geometry.coordinates;

                                // Handle pickup, via points, and drop separately
                                if (inputId === 'pickup') {
                                    pickupCoordinates = coordinates;
                                    pickupName = feature.place_name; // Store pickup name

                                } else if (inputId === 'via') {
                                    waypointsCoordinates[0] = coordinates;
                                    waypointsNames[0] = feature.place_name; // Store Via 1 name

                                } else if (inputId === 'viaTwo') {
                                    waypointsCoordinates[1] = coordinates;
                                    waypointsNames[1] = feature.place_name; // Store Via 2 name

                                } else if (inputId === 'viaThree') {
                                    waypointsCoordinates[2] = coordinates;
                                    waypointsNames[2] = feature.place_name; // Store Via 3 name

                                } else if (inputId === 'viaFour') {
                                    waypointsCoordinates[3] = coordinates;
                                    waypointsNames[3] = feature.place_name; // Store Via 4 name

                                } else if (inputId === 'drops') {
                                    dropCoordinates = coordinates;
                                    dropName = feature.place_name; // Store drop name
                                }

                                // Update markers and route
                                updateMarkers();
                                checkAndFetchRoute();
                            });
                            suggestionsContainer.appendChild(suggestionItem);
                        });
                    } else {
                        suggestionsContainer.style.display = 'none';
                    }
                })
                .catch(error => {
                    console.error('Error fetching suggestions:', error);
                });
        } else {
            suggestionsContainer.style.display = 'none';
        }
    });

    document.addEventListener('click', function (event) {
        if (!suggestionsContainer.contains(event.target) && event.target !== inputElement) {
            suggestionsContainer.style.display = 'none';
        }
    });
}



// Attach geocoder suggestions to the inputs
addGeocoderToInput('pickup');
addGeocoderToInput('via');      // ID for first via location
addGeocoderToInput('viaTwo');   // ID for second via location
addGeocoderToInput('viaThree'); // ID for third via location
addGeocoderToInput('viaFour');  // ID for fourth via location
addGeocoderToInput('drops');

// Route event listener
directions.on('route', function (e) {
    
    map.setPaintProperty('directions-route-line-casing', 'line-width', 3); // Outer line width
    map.setPaintProperty('directions-route-line-casing', 'line-color', '#6f42c1 '); // Milk white color for outer line

    // Set the inner route line width and color (if needed)
    map.setPaintProperty('directions-route-line', 'line-width', 1); // Inner line width
    map.setPaintProperty('directions-route-line', 'line-color', '#6f42c1 '); // Example color for inner route line

    // Additional code for calculating distance and time remains unchanged
    const distanceKm = e.route[0].distance / 1000; // Convert meters to kilometers
    const distanceMiles = distanceKm * 0.621371; // Convert kilometers to miles
    const totalDuration = e.route[0].duration / 60; // Convert seconds to minutes

    const hours = Math.floor(totalDuration / 60);
    const minutes = Math.round(totalDuration % 60);
    const formattedDuration = hours > 0 ? `${hours} hrs ${minutes} mins` : `${minutes} mins`;

    document.getElementById('display_distance').value = distanceMiles.toFixed(2);
    document.getElementById('Times').value = formattedDuration;
    
      const routeSummary = document.getElementById('routesummary');
 routeSummary.innerHTML = `<h4>Distance: ${distanceMiles.toFixed(2)} miles, Duration: ${formattedDuration}</h4>`;

        console.log('Pickup:', pickupCoordinates);
console.log('Waypoints:', waypointsCoordinates);
console.log('Drop:', dropCoordinates);
 updateMarkers();
    calculateDistanceAndFare();
});



// Initial calculation on page load if locations are set
calculateDistanceAndFare();





function formatDate(date) {
  const year = date.getUTCFullYear();
  const month = String(date.getUTCMonth() + 1).padStart(2, '0'); // Month is zero-based
  const day = String(date.getUTCDate()).padStart(2, '0');
  return `${day}/${month}/${year}`;

}

function updateDate() {
  const currentDate = new Date();
  const formattedDate = formatDate(currentDate);
  document.getElementById('dateInput').value = formattedDate;
  document.getElementById('pickupDate').value = formattedDate;
  document.getElementById('retPickupDate').value = formattedDate;
}

// Function to get London time
function getLondonTime() {
  const options = {
    timeZone: 'Europe/London',
    hour12: false, 
    hour: '2-digit',
    minute: '2-digit',
  };
  const londonTime = new Date().toLocaleTimeString('en-US', options);
  return londonTime;
}

// Function to update the time input field with London time
function updateTime() {
  const londonTime = getLondonTime();
  document.getElementById('timeInput').value = londonTime;
  document.getElementById('pickupTime').value = londonTime;
  document.getElementById('returnPickupTime').value = londonTime;
}


updateDate();
updateTime();


let updateTimeInterval = setInterval(updateTime, 60000); // 60000ms = 1 minute


// Event listener for the .view button
$('.view, .edit, .onboardview, .onboardedit, .multijobs, .oneWay').on('click', function () {
    console.log("Hit view  button");
    clearInterval(updateTimeInterval);  
      document.getElementById('returnPickupTime').value = '';

  
  
});
$('#clear, #returnTrip').on('click', function () {
  updateDate();
  updateTime();
  $("#newjobId").show();
  $("#jobId").hide();
});


  var pT = document.getElementById("Payment_Type");
  var Ac = document.getElementById("Account");
  console.log("dfhg", pT.value);

  pT.addEventListener("change", function () {
    if (pT.value === "Account") {
      // Enable the "Account" field
      Ac.disabled = false;
    } else {
      // Disable the "Account" field
      Ac.disabled = true;
    }
  });


  $(document).ready(function (){
    $('#addVia').click(function(){
      $('#viaTwo, #viaThree, #viaFour').toggle();
    });
  });

// $(document).ready(function(){
//   // Define the function to calculate fare
//   function calculateDistanceAndFare() {

//     // Retrieve location values from the form
//     var pickup = $('#pickup').val();
//     var drop = $('#drops').val();
//     var carType = $('#cartype').val();
//     var distance = $("#distance_display").val();
    
//     console.log("pickup", pickup)
//     console.log("drop", drop)
//     console.log("car", carType)
//     console.log("distance", distance)
    
    
//     if (pickup && drop) {
     
//             $.ajax({
//               type: 'POST',
//               url: './action/Submit.php',
//               data: {
//                 pickup: pickup,
//                 drop: drop,
//                 carType: carType,
//                 distance: distance
//               },
//               cache: false,
//               success: function (response) {
//                 console.log("response:", response);
//                 // Update the fare display with the calculated fare
//                 $('#priceVal').val( response);

//               },
//               error: function () {
//                 console.log("error")
//               }
//             });
//           } else {
//           console.log("dfdsfds")
//           }
//   }
  
//     // Add event listeners to car type, pickup location, and drop location inputs
//     $('#cartype, #pickup, #drops').on('input change', function () {
//       calculateDistanceAndFare();
//     });
  
//     // Initially, calculate the fare based on the initial values if both locations are provided
//     calculateDistanceAndFare();
// });
