document.addEventListener("DOMContentLoaded", function() {
clearBookings();
loadBookings();

const oneWayElement = document.getElementById('oneWay');
const returnTripElement = document.getElementById('returnTrip');

if (oneWayElement) {
oneWayElement.checked = true;
oneWayElement.addEventListener('change', function() {
if (oneWayElement.checked) {
returnTripElement.checked = false;
toggleReturnTripFields();
}
});
}

if (returnTripElement) {
returnTripElement.checked = false;
returnTripElement.addEventListener('change', function() {
if (returnTripElement.checked) {
oneWayElement.checked = false;
toggleReturnTripFields();
}
});
}

// Initialize the state based on default checked status
toggleReturnTripFields();
});

function toggleReturnTripFields() {
const returnTripElement = document.getElementById('returnTrip');
const oneWayElement = document.getElementById('oneWay');
const returnDate = document.getElementById('retPickupDate');
const returnTime = document.getElementById('returnPickupTime');

if (returnTripElement.checked) {
returnDate.disabled = false;
returnTime.disabled = false;
} else {
returnDate.disabled = true;
returnTime.disabled = true;
}
}

function collectTimes() {
    // Select all elements with the class 'time-input'
    const timeInputs = document.querySelectorAll('.time-input');
    const timesArray = [];

    // Iterate through the selected elements and push their values into timesArray
    timeInputs.forEach(input => {
        timesArray.push(input.value);
    });

    return timesArray;
}

function collectReturnTimes() {
    // Select all elements with the class 'return-time-input'
    const returnTimeInputs = document.querySelectorAll('.return-time-input');
    const returnTimesArray = [];

    // Iterate through the selected elements and push their values into returnTimesArray
    returnTimeInputs.forEach(input => {
        returnTimesArray.push(input.value);
    });

    return returnTimesArray;
}

// Example usage
const timesArray = collectTimes();
console.log(timesArray); // Outputs an array of time values, e.g., ["09:00", "10:00", "11:00"]

const returnTimesArray = collectReturnTimes();
console.log(returnTimesArray); // Outputs an array of return time values, e.g., ["17:00", "18:00", "19:00"]

function clearBookings() {
    localStorage.removeItem('bookings');
}

function formatDate(date) {
    const day = String(date.getDate()).padStart(2, '0');
    const month = String(date.getMonth() + 1).padStart(2, '0'); // Month is zero-based
    const year = date.getFullYear();
    return `${day}/${month}/${year}`; 
}

function parseDate(input) {
    const [day, month, year] = input.split('/');
    return new Date(`${year}-${month}-${day}`);
}

function createBookings() {
    const daysCount = parseInt(document.getElementById('daysCount').value);
    const startDateInput = document.getElementById('pickupDate').value;
    const startTime = document.getElementById('pickupTime').value;
    const fare = document.getElementById('priceVal').value;
    const isReturnTrip = document.getElementById('returnTrip').checked;
    const returnDateInput = document.getElementById('retPickupDate').value;
    const returnTime = document.getElementById('returnPickupTime').value;

    // Check if start date input is valid
    if (!startDateInput) {
        alert('Please enter a valid start date');
        return;
    }

    // Parse the start date input into a Date object
    const startDate = parseDate(startDateInput);
    
    // Check if start date is a valid date
    if (isNaN(startDate.getTime())) {
        alert('Invalid start date');
        return;
    }

    // Check if return date input is valid if return trip is selected
    if (isReturnTrip && !returnDateInput) {
        alert('Please enter a valid return date');
        return;
    }

    let bookings = JSON.parse(localStorage.getItem('bookings')) || [];

    for (let i = 0; i < daysCount; i++) {
        const bookingDate = new Date(startDate);
        bookingDate.setDate(startDate.getDate() + i);

        let returnDate = null;
        if (isReturnTrip) {
            returnDate = parseDate(returnDateInput);
            returnDate.setDate(returnDate.getDate() + i); // Adjust the return date for each day

            // Check if return date is a valid date
            if (isNaN(returnDate.getTime())) {
                alert('Invalid return date');
                return;
            }
        }

        bookings.push({
            fare: fare,
            date: formatDate(bookingDate),
            time: startTime,
            returnDate: returnDate ? formatDate(returnDate) : '',
            returnTime: returnTime,
        });
    }

    localStorage.setItem('bookings', JSON.stringify(bookings));
    displayBookings();
}

function displayBookings() {
    const bookings = JSON.parse(localStorage.getItem('bookings')) || [];
    const tbody = document.getElementById('bookingsTable').querySelector('tbody');
    tbody.innerHTML = '';

    bookings.forEach((booking, index) => {
        const row = tbody.insertRow();

        const dateCell = row.insertCell();
        dateCell.innerHTML = `<input style="width:100px;background-color: rgb(0 0 0 / 0%);border: 0px;outline: 0px white;height: 20px !important;" type="text" value="${booking.date}" onchange="updateBooking(${index}, this.value, 'date')">`;

        const timeCell = row.insertCell();
        timeCell.innerHTML = `<input style="width:100px;background-color: rgb(0 0 0 / 0%);border: 0px;outline: 0px white;height: 20px !important;" class="time-input" type="text" value="${booking.time}" onchange="updateBooking(${index}, this.value, 'time')">`;

        const returnDateCell = row.insertCell();
        returnDateCell.innerHTML = `<input style="width:100px;background-color: rgb(0 0 0 / 0%);border: 0px;outline: 0px white;height: 20px !important;" type="text" value="${booking.returnDate}" onchange="updateBooking(${index}, this.value, 'returnDate')" ${booking.returnDate ? '' : 'disabled'}>`;

        const returnTimeCell = row.insertCell();
        returnTimeCell.innerHTML = `<input style="width:100px;background-color: rgb(0 0 0 / 0%);border: 0px;outline: 0px white;height: 20px !important;" class="return-time-input" type="text" value="${booking.returnTime}" onchange="updateBooking(${index}, this.value, 'returnTime')" ${booking.returnTime ? '' : 'disabled'}>`;

        const fareCell = row.insertCell();
        fareCell.innerHTML = `<input style="width:100px;background-color: rgb(0 0 0 / 0%);border: 0px;outline: 0px white;height: 20px !important;" type="text" value="£${booking.fare}" onchange="updateBooking(${index}, this.value, 'fare')">`;

        const actionsCell = row.insertCell();
        actionsCell.innerHTML = `<button style="padding: 2px 10px;text-decoration: none;font-size: 11px;border: none;border-radius: 4px;font-weight: 700;" class="btn btn-sm background" type="button" onclick="deleteBooking(${index})">Delete</button>`;
    });
}

function updateBooking(index, newValue, field) {
    let bookings = JSON.parse(localStorage.getItem('bookings')) || [];
    bookings[index][field] = newValue;
    localStorage.setItem('bookings', JSON.stringify(bookings));
}

function deleteBooking(index) {
    let bookings = JSON.parse(localStorage.getItem('bookings')) || [];
    bookings.splice(index, 1);
    localStorage.setItem('bookings', JSON.stringify(bookings));
    displayBookings();
}

function loadBookings() {
    displayBookings();
}

// AJAX Call
$('#multiJobsSave').click(function() {
    $('#name, #email, #phone, #pickup, #drops').removeClass('empty-field');
    var name = $('#name').val();
    var email = $('#email').val();
    var phone = $('#phone').val();
    var carType = $('#cartype').val();
    var pickup = $('#pickup').val();
    var drop = $('#drops').val();
    var pickupLatLon = $('#pickupLocationLonLat').val();
    var dropLatLon = $('#dropoffLocationLonLat').val();
    var date = $('#pickupDate').val();
    var returnDate = $('#retPickupDate').val();
    var timesArray = collectTimes(); // Collect the times for each day
    var returnTimesArray = collectReturnTimes(); // Collect the return times for each day
    var viaLocation = $('#via').val();
    var viaLocationTwo = $('#viaTwo').val();
    var distance = parseFloat($('#display_distance').val());
    var pax = $('#pax').val(); 
    var luggage = $('#luggage').val();
    var routeSelect = $('#routeSelect').val();
    var fare = parseFloat($('#priceVal').val());
    var message = $('#message').val(); 
    var jobtype = $('#jobtype').val();
    var Payment_Type = $('#Payment_Type').val();
    var Account = $('#Account').val();
    var DriverID = $('#driver').val();
    var daysCount = parseInt($('#daysCount').val(), 10);
    var isReturnTrip = $('#returnTrip').is(':checked'); // Check if return trip is selected

    console.log("Days", daysCount);
    console.log("Times", timesArray);
    console.log("Return Times", returnTimesArray);
    console.log("via two:", viaLocationTwo);

    if (!name) {
      $("#name").addClass("empty-field");
      return;
    }
    if (!phone) {
      $("#phone").addClass("empty-field");
      return;
    }
    if (!pickup) {
      $("#pickup").addClass("empty-field");
      return;
    }
    if (!drop) {
      $("#drops").addClass("empty-field");
      return;
    }

    $.ajax({
        type: 'POST',
        url: 'action/save_multiple_jobs.php',
        data: {
            name: name,
            phone: phone,
            email: email,
            message: message,
            carType: carType,
            pickup: pickup,
            drop: drop,
            date: date,
            returnDate: returnDate,
            times: timesArray,
            returnTimes: returnTimesArray,
            isReturnTrip: isReturnTrip,
            via: viaLocation,
            viaTwo: viaLocationTwo,
            distance: distance,
            fare: fare,
            jobtype: jobtype,
            Payment_Type: Payment_Type,
            Account: Account,
            driverId: DriverID,
            pax: pax,
            luggage: luggage,
            routeSelect: routeSelect,
            pickupLatLon: pickupLatLon,
            dropLatLon: dropLatLon,
            daysCount: daysCount
        },
        success: function (response) {
            console.log("Response from the server:", response);  
            toastr.options = {
                "closeButton": true,
                "debug": false,
                "newestOnTop": false,
                "progressBar": false,
                "positionClass": "toast-bottom-right",
                "preventDuplicates": true,
                "onclick": null,
                "showDuration": "300",
                "hideDuration": "1000",
                "timeOut": "5000",
                "extendedTimeOut": "1000",
                "showEasing": "swing",
                "hideEasing": "linear",
                "showMethod": "fadeIn",
                "hideMethod": "fadeOut",
                "toastClass": "toastr-green" 
            };
     
            toastr.success("Job saved successfully", "Success");
            $('#name').val('');
            $('#email').val('');
            $('#phone').val('');
            $('#pickup').val('');
            $('#drops').val('');
            $('#via').val('');
            $('#viaTwo').val('');
            $('#luggage').val('');
            $('#display_distance').val('');
            $('#priceVal').val('');
            $('#message').val('');
            $('#cartype').val($('#cartype option:first').val());
            $('#routeSelect').val($('#routeSelect option:first').val());
            $('#Payment_Type').val($('#Payment_Type option:first').val());
            $('#Account').val($('#Account option:first').val());
            $('#jobtype').val($('#jobtype option:first').val());
            $('#driver').val('');
            $('#pickupLocationLonLat').val('');
            $('#dropLocationLonLat').val('');
            $('#Times').val('');
            fetchBookings();
            dispatch();
            $("#drops").prop("disabled", false);
            updateDate();
            updateTime();
            $("#newjobId").show();
            $("#jobId").hide();
        },
        error: function () {
            alert("Error occurred while saving data.");
        }
    });
});

$("#closed").click(function() {
    clearBookings(); // Clear all bookings
            displayBookings();
});
