<?php
require __DIR__ . "/vendor/autoload.php";

use Dompdf\Dompdf;
use Dompdf\Options;

$data = isset($_POST['data']) ? json_decode($_POST['data'], true) : null;
$totalFare = isset($_POST['totalFare']) ? $_POST['totalFare'] : '';
$totalJobs = isset($_POST['totalJobs']) ? $_POST['totalJobs'] : '';

if ($data !== null && is_array($data) && !empty($data)) {
    $html = '<html>
    <head>
    <style>
    body {
        font-family: Arial, sans-serif;
    }

    h1 {
        color: #6f42c1;
        text-align: center;
        margin-bottom: 20px;
    }

    table {
        width: 100%;
        border-collapse: collapse;
        margin-bottom: 20px;
    }

    th, td {
        padding: 5px 10px !important;
        font-size: 14px;
        font-weight: bold;
        border: 1px solid #ccc;
    }

    th {
        background: #6f42c1 linear-gradient(180deg, #855eca, #6f42c1) repeat-x;
        color: white;
        white-space: nowrap;
    }

    td {
        padding: 5px 10px;
        font-size: 10px;
        border: 1px solid #ccc; 
    }

    h2 {
        color: #6f42c1;
        text-align: center;
        margin-top: 20px;
    }

    tfoot {
        font-weight: bold;
    }
    </style>
    </head>
    <body>
    <div class="container">';

    $html .= '<h1>Company Income</h1>';
    $html .= '<table>';
    $html .= '<thead>';
    $html .= '<tr>';
    $html .= '<th>Date&Time</th>';
    $html .= '<th>Pick Up</th>';
    $html .= '<th>Drop Off</th>';
    $html .= '<th>Name</th>';
    $html .= '<th>Phone</th>';
    $html .= '<th>Price</th>';
    $html .= '<th>Payment_Type</th>';
    $html .= '<th>Driver</th>';
    $html .= '</tr>';
    $html .= '</thead>';
    $html .= '<tbody>';

    foreach ($data as $row) {
        $html .= '<tr>';
        $html .= '<td>' . htmlspecialchars($row[0]) . '</td>';
        $html .= '<td>' . htmlspecialchars($row[1]) . '</td>';
        $html .= '<td>' . htmlspecialchars($row[2]) . '</td>';
        $html .= '<td>' . htmlspecialchars($row[3]) . '</td>';
        $html .= '<td>' . htmlspecialchars($row[4]) . '</td>';
        $html .= '<td>' . htmlspecialchars($row[5]) . '</td>';
        $html .= '<td>' . htmlspecialchars($row[6]) . '</td>';
        $html .= '<td>' . htmlspecialchars($row[7]) . '</td>';
        $html .= '</tr>';
    }

    $html .= '</tbody>';
    $html .= '<tfoot>';
    $html .= '<tr>';
    $html .= '<td colspan="4">Total Fare: ' . htmlspecialchars($totalFare) . '</td>';
    $html .= '<td colspan="4">Total Jobs: ' . htmlspecialchars($totalJobs) . '</td>';
    $html .= '</tr>';
    $html .= '</tfoot>';
    $html .= '</table>';

    $html .= '<h2>Thank You</h2>';

    $html .= '</div></body></html>';

    $options = new Options;
    $options->setChroot(__DIR__);
    $options->setIsHtml5ParserEnabled(true);
    $options->setIsPhpEnabled(true);

    $dompdf = new Dompdf($options);

    $dompdf->setPaper("A4", "landscape"); // Change to landscape mode
    $dompdf->loadHtml($html);
    $dompdf->render();

    header('Content-Type: application/pdf');
    header('Content-Disposition: attachment;filename="all_completed_jobs.pdf"');
    header('Cache-Control: private, max-age=0, must-revalidate');
    header('Pragma: public');
    header('Expires: Sat, 26 Jul 1997 05:00:00 GMT');

    echo $dompdf->output();
} else {
    echo 'Error: No data received or invalid data format.';
}

?>
