<?php
include("db/db.php"); // Include database connection

// Check if the user is logged in
if (!isset($_SESSION['log'])) {
    header("Location: ./login.php");
    exit;
}

$role = $_SESSION['admin']; // Fetch the role from the session
$userId = $_SESSION['user_id']; // Fetch the user ID
$isFromUserTable = $_SESSION['is_from_user_table']; // Flag to know if the user is from user table or company_user table

// Define icons for each page
$icons = [
    'Dashboard' => 'fas fa-tachometer-alt',
    'Management' => 'fa fa-line-chart',
    'Jobs' => 'fas fa-tasks',
    'Drivers' => 'fa fa-user',
    'Reports' => 'fas fa-file-invoice',
    'Accounts' => 'fa fa-bank',
    'Plotting' => 'fas fa-tasks',
    'Tracking' => 'fas fa-plus',
    'Customer' => 'fa fa-users',
    'Call Logs' => 'fa fa-phone-volume',
    'Drivers Log' => 'fa fa-clock-rotate-left',
    'Setting' => 'fa fa-gear',
    'Logout' => 'fas fa-sign-out-alt'
];

// Case 1: If admin is from the user table, show all buttons
if ($isFromUserTable && $role == 1) {
    $pages = [
        'Dashboard' => 'index.php',
        'Management' => 'fare.php',
        'Jobs' => 'Jobs.php',
        'Drivers' => 'drivers.php',
        'Reports' => 'earning.php',
        'Accounts' => 'accounts.php',
        'Plotting' => 'Plot.php',
        'Tracking' => 'driverTracking.php',
        'Customer' => 'customer_list.php',
        'Call Logs' => 'call_log_history.php',
        'Setting' => 'config.php',
        'Logout' => './action/logout.php'
    ];
} else {
    // Case 2: Admin is from company_user table, check their role and allowed pages
    $pages = [];
    $query = "SELECT * FROM company_user WHERE id = ? AND role = ?";
    $stmt = $con->prepare($query);
    $stmt->bind_param('ii', $userId, $role);
    $stmt->execute();
    $result = $stmt->get_result();
    $permissions = $result->fetch_assoc();

    if ($permissions) {
        // Based on the fetched permissions, display only allowed links
        if ($permissions['dasboard'] == 1) $pages['Dashboard'] = 'index.php';
        if ($permissions['management'] == 1) $pages['Management'] = 'fare.php';
        if ($permissions['job'] == 1) $pages['Jobs'] = 'Jobs.php';
        if ($permissions['drivers'] == 1) $pages['Drivers'] = 'drivers.php';
        if ($permissions['reports'] == 1) $pages['Reports'] = 'earning.php';
        if ($permissions['accounts'] == 1) $pages['Accounts'] = 'accounts.php';
        if ($permissions['plotting'] == 1) $pages['Plotting'] = 'Plot.php';
        if ($permissions['tracking'] == 1) $pages['Tracking'] = 'driverTracking.php';
        if ($permissions['customer'] == 1) $pages['Customer'] = 'customer_list.php';
        if ($permissions['call_logs'] == 1) $pages['Call Logs'] = 'call_log_history.php';
        if ($permissions['settings'] == 1) $pages['Setting'] = 'config.php';
    }

    // Logout link is always available
    $pages['Logout'] = './action/logout.php';
}

?>
<!-- Styles -->
<style>
    .navbars .container-fluid .col-12 .navbar-list li a {
        color: <?php echo $row['navbar_font']?> !important;
        font-family: <?php echo $row['navbarfont_family']?> !important;
    }
    i {
        color: <?php echo $row['icon_color']?> !important;
    }
    .navbars .container-fluid .col-12 .navbar-list li a {
        text-decoration: none;
        color: #c2c7d0;
        font-weight: 700;
    }
    .logout-item {
        margin-left: auto; /* Push logout to the right */
    }
</style>

<!-- Navbar -->
<nav class="navbars" style="background:<?php echo $row['navbar_color']?> !important">
    <div class="container-fluid">
        <div class="row">
            <div class="col-12">
                <div class="content">
                    <div class="list-box">
                        <ul class="navbar-list">
                            <?php foreach ($pages as $name => $link): ?>
                                <?php if ($name != 'Logout'): // Separate Logout item ?>
                                    <li>
                                        <a href="<?php echo $link; ?>">
                                            <span><i class="<?php echo $icons[$name]; ?>"></i></span>
                                            <?php echo $name; ?>
                                        </a>
                                    </li>
                                <?php endif; ?>
                            <?php endforeach; ?>
                            <li class="logout-item"> <!-- Special class for Logout -->
                                <a href="<?php echo $pages['Logout']; ?>">
                                    <span><i class="<?php echo $icons['Logout']; ?>"></i></span>
                                    Logout
                                </a>
                            </li>
                        </ul>
                    </div>
                </div>
            </div>
        </div>
    </div>
</nav>
